@@ -81,18 +81,20 @@ const char *  g_irepository_load_typelib  (GIRepository *repository,
 					   GTypelib     *typelib,
 					   GIRepositoryLoadFlags flags,
 					   GError      **error);
-gboolean      g_irepository_is_registered (GIRepository *repository, 
-					   const gchar  *namespace);
+gboolean      g_irepository_is_registered (GIRepository *repository,
+					   const gchar  *namespace,
+					   const gchar  *version);
 GIBaseInfo *  g_irepository_find_by_name  (GIRepository *repository,
 					   const gchar  *namespace,
 					   const gchar  *name);
-gboolean      g_irepository_require       (GIRepository *repository,
-					   const char   *namespace,
+GTypelib *    g_irepository_require       (GIRepository *repository,
+					   const gchar  *namespace,
+					   const gchar  *version,
 					   GIRepositoryLoadFlags flags,
 					   GError      **error);
 gchar      ** g_irepository_get_dependencies (GIRepository *repository,
-					      const char *namespace);
-gchar      ** g_irepository_get_namespaces (GIRepository *repository);
+					      const gchar  *namespace);
+gchar      ** g_irepository_get_loaded_namespaces (GIRepository *repository);
 GIBaseInfo *  g_irepository_find_by_gtype (GIRepository *repository,
 					   GType         gtype);
 gint          g_irepository_get_n_infos   (GIRepository *repository,
@@ -104,6 +106,9 @@ const gchar * g_irepository_get_typelib_path   (GIRepository *repository,
 						const gchar  *namespace);
 const gchar * g_irepository_get_shared_library (GIRepository *repository,
 						const gchar  *namespace);
+const gchar * g_irepository_get_version (GIRepository *repository,
+					 const gchar  *namespace);
+
 /* Typelib */
 
 GTypelib *   g_typelib_new_from_memory       (guchar       *memory,
@@ -112,14 +117,17 @@ GTypelib *   g_typelib_new_from_const_memory (const guchar *memory,
                                                 gsize         len);
 GTypelib *   g_typelib_new_from_mapped_file  (GMappedFile  *mfile);
 void          g_typelib_free                  (GTypelib    *typelib);
-void          g_typelib_set_module            (GTypelib    *typelib,
-                                                GModule      *module);
+
+gboolean      g_typelib_symbol                (GTypelib    *typelib,
+                                               const gchar *symbol_name,
+                                               gpointer    *symbol);
 const gchar * g_typelib_get_namespace         (GTypelib    *typelib);
 
 typedef enum
 {
   G_IREPOSITORY_ERROR_TYPELIB_NOT_FOUND,
   G_IREPOSITORY_ERROR_NAMESPACE_MISMATCH,
+  G_IREPOSITORY_ERROR_NAMESPACE_VERSION_CONFLICT,
   G_IREPOSITORY_ERROR_LIBRARY_NOT_FOUND
 } GIRepositoryError;
 
@@ -182,7 +190,8 @@ typedef enum
   GI_FUNCTION_IS_CONSTRUCTOR = 1 << 1,
   GI_FUNCTION_IS_GETTER      = 1 << 2,
   GI_FUNCTION_IS_SETTER      = 1 << 3,
-  GI_FUNCTION_WRAPS_VFUNC    = 1 << 4
+  GI_FUNCTION_WRAPS_VFUNC    = 1 << 4,
+  GI_FUNCTION_THROWS         = 1 << 5
 } GIFunctionInfoFlags;
 
 const gchar *           g_function_info_get_symbol     (GIFunctionInfo *info);
@@ -267,6 +276,7 @@ GITypeInfo *           g_arg_info_get_type               (GIArgInfo *info);
 /* GITypeInfo */
 
 typedef enum {
+  /* Basic types */
   GI_TYPE_TAG_VOID      =  0,
   GI_TYPE_TAG_BOOLEAN   =  1,
   GI_TYPE_TAG_INT8      =  2,
@@ -285,16 +295,23 @@ typedef enum {
   GI_TYPE_TAG_SIZE      = 15,
   GI_TYPE_TAG_FLOAT     = 16,
   GI_TYPE_TAG_DOUBLE    = 17,
-  GI_TYPE_TAG_UTF8      = 18,
-  GI_TYPE_TAG_FILENAME  = 19,
-  GI_TYPE_TAG_ARRAY     = 20,
-  GI_TYPE_TAG_INTERFACE = 21,
-  GI_TYPE_TAG_GLIST     = 22,
-  GI_TYPE_TAG_GSLIST    = 23,
-  GI_TYPE_TAG_GHASH     = 24,
-  GI_TYPE_TAG_ERROR     = 25
+  GI_TYPE_TAG_TIME_T    = 18,
+  GI_TYPE_TAG_GTYPE     = 19,
+  GI_TYPE_TAG_UTF8      = 20,
+  GI_TYPE_TAG_FILENAME  = 21,
+  /* Non-basic types */
+  GI_TYPE_TAG_ARRAY     = 22,
+  GI_TYPE_TAG_INTERFACE = 23,
+  GI_TYPE_TAG_GLIST     = 24,
+  GI_TYPE_TAG_GSLIST    = 25,
+  GI_TYPE_TAG_GHASH     = 26,
+  GI_TYPE_TAG_ERROR     = 27
+  /* Note - there is only room currently for 32 tags.
+   * See docs/typelib-format.txt SimpleTypeBlob definition */
 } GITypeTag;
 
+#define G_TYPE_TAG_IS_BASIC(tag) (tag < GI_TYPE_TAG_ARRAY)
+
 const gchar*           g_type_tag_to_string            (GITypeTag   type);
 
 gboolean               g_type_info_is_pointer          (GITypeInfo *info);
@@ -303,6 +320,7 @@ GITypeInfo *           g_type_info_get_param_type      (GITypeInfo *info,
 						        gint       n);
 GIBaseInfo *           g_type_info_get_interface       (GITypeInfo *info);
 gint                   g_type_info_get_array_length    (GITypeInfo *info);
+gint                   g_type_info_get_array_fixed_size(GITypeInfo *info);
 gboolean               g_type_info_is_zero_terminated  (GITypeInfo *info);
 
 gint                   g_type_info_get_n_error_domains (GITypeInfo *info);
@@ -346,6 +364,8 @@ gint                   g_union_info_get_discriminator_offset (GIUnionInfo *info)
 GITypeInfo *           g_union_info_get_discriminator_type (GIUnionInfo *info);
 GIConstantInfo *       g_union_info_get_discriminator      (GIUnionInfo *info,
 					                    gint         n);
+GIFunctionInfo *       g_union_info_find_method    (GIUnionInfo *info,
+                                                    const gchar *name);
 
 
 /* GIStructInfo */
@@ -374,6 +394,7 @@ GIValueInfo  *         g_enum_info_get_value                (GIEnumInfo      *in
 
 const gchar *          g_object_info_get_type_name 	    (GIObjectInfo    *info);
 const gchar *          g_object_info_get_type_init 	    (GIObjectInfo    *info);
+gboolean               g_object_info_get_abstract           (GIObjectInfo    *info);
 GIObjectInfo *         g_object_info_get_parent             (GIObjectInfo    *info);
 gint                   g_object_info_get_n_interfaces       (GIObjectInfo    *info);
 GIInterfaceInfo *      g_object_info_get_interface          (GIObjectInfo    *info,
